@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2019 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +12,8 @@
 
 #include <QIcon>
 
+QT_FORWARD_DECLARE_CLASS(QTextCodec)
+
 class KCodecActionExt : public KSelectAction
 {
 	Q_OBJECT
@@ -29,7 +31,11 @@ Q_SIGNALS:
 	void triggered(QTextCodec *codec);
 
 protected Q_SLOTS:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	void slotActionTriggered(QAction *) override {}
+#else
 	void actionTriggered(QAction *) override {}
+#endif
 
 private:
 	void init();
