@@ -1,11 +1,12 @@
 /*
-    SPDX-FileCopyrightText: 2010-2020 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "config.h"
 
+#include "appglobal.h"
 #include "application.h"
 #include "core/subtitleiterator.h"
 #include "errors/finderrorsdialog.h"
@@ -17,7 +18,7 @@ using namespace SubtitleComposer;
 void
 Application::selectNextError()
 {
-	const int idx = m_linesWidget->currentLineIndex();
+	const int idx = m_mainWindow->m_linesWidget->currentLineIndex();
 	if(!m_errorFinder->findNext(idx)) {
 		m_lastFoundLine = nullptr;
 		m_errorFinder->find(idx, false);
@@ -27,7 +28,7 @@ Application::selectNextError()
 void
 Application::selectPreviousError()
 {
-	const int idx = m_linesWidget->currentLineIndex();
+	const int idx = m_mainWindow->m_linesWidget->currentLineIndex();
 	if(!m_errorFinder->findPrevious(idx)) {
 		m_lastFoundLine = nullptr;
 		m_errorFinder->find(idx, true);
@@ -38,18 +39,18 @@ void
 Application::detectErrors()
 {
 	m_lastFoundLine = nullptr;
-	m_errorFinder->find(m_linesWidget->currentLineIndex());
+	m_errorFinder->find(m_mainWindow->m_linesWidget->currentLineIndex());
 }
 
 void
 Application::clearErrors()
 {
-	m_subtitle->clearErrors(RangeList(Range::full()), SubtitleLine::AllErrors);
+	appSubtitle()->clearErrors(RangeList(Range::full()), SubtitleLine::AllErrors);
 }
 
 void
 Application::toggleSelectedLinesMark()
 {
-	m_subtitle->toggleMarked(m_linesWidget->selectionRanges());
+	appSubtitle()->toggleMarked(m_mainWindow->m_linesWidget->selectionRanges());
 }
 
