@@ -1,12 +1,13 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "playerconfigwidget.h"
 
+#include "appglobal.h"
 #include "videoplayer/videoplayer.h"
 #include "widgets/layeredwidget.h"
 #include "widgets/textoverlaywidget.h"
@@ -44,7 +45,7 @@ PlayerConfigWidget::PlayerConfigWidget(QWidget *parent)
 	connect(kcfg_OutlineWidth, QOverload<int>::of(&QSpinBox::valueChanged), this, &PlayerConfigWidget::onOutlineWidthChanged);
 
 	connect(static_cast<KConfigDialog *>(parent), &KConfigDialog::settingsChanged, this, [](const QString &){
-		VideoPlayer::instance()->setVolume(VideoPlayer::instance()->volume());
+		videoPlayer()->setVolume(videoPlayer()->volume());
 	});
 }
 
