@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -45,15 +45,13 @@ Subtitle::Subtitle(double framesPerSecond)
 	  m_secondaryDirtyState(false),
 	  m_secondaryCleanIndex(0),
 	  m_framesPerSecond(framesPerSecond),
-	  m_stylesheet(new RichCSS()),
+	  m_stylesheet(new RichCSS(this)),
 	  m_formatData(nullptr)
 {}
 
 Subtitle::~Subtitle()
 {
 	qDeleteAll(m_lines);
-
-	delete m_stylesheet;
 	delete m_formatData;
 }
 
@@ -260,13 +258,13 @@ Subtitle::changeFramesPerSecond(double toFramesPerSecond, double fromFramesPerSe
 SubtitleLine *
 Subtitle::line(int index)
 {
-	return index < 0 || index >= m_lines.count() ? nullptr : m_lines.at(index).obj();
+	return index < 0 || size_t(index) >= m_lines.size() ? nullptr : m_lines.at(index).obj();
 }
 
 const SubtitleLine *
 Subtitle::line(int index) const
 {
-	return index < 0 || index >= m_lines.count() ? nullptr : m_lines.at(index).obj();
+	return index < 0 || size_t(index) >= m_lines.size() ? nullptr : m_lines.at(index).obj();
 }
 bool
 Subtitle::hasAnchors() const
@@ -281,7 +279,7 @@ Subtitle::hasAnchors() const
 bool
 Subtitle::isLineAnchored(int index) const
 {
-	if(index < 0 || index >= m_lines.count())
+	if(index < 0 || size_t(index) >= m_lines.size())
 		return false;
 
 	return isLineAnchored(m_lines[index]);
@@ -299,7 +297,7 @@ Subtitle::isLineAnchored(const SubtitleLine *line) const
 void
 Subtitle::toggleLineAnchor(int index)
 {
-	if(index < 0 || index >= m_lines.count())
+	if(index < 0 || size_t(index) >= m_lines.size())
 		return;
 
 	toggleLineAnchor(m_lines[index]);
@@ -357,7 +355,7 @@ Subtitle::insertLine(SubtitleLine *line)
 void
 Subtitle::insertLine(SubtitleLine *line, int index)
 {
-	Q_ASSERT(index >= 0 && index <= m_lines.count());
+	Q_ASSERT(index >= 0 && size_t(index) <= m_lines.size());
 	QList<SubtitleLine *> lines;
 	lines.append(line);
 	processAction(new InsertLinesAction(this, lines, index));
@@ -372,7 +370,7 @@ Subtitle::insertNewLine(int index, bool insertAfter, SubtitleTarget target)
 		index = count();
 
 	SubtitleLine *newLine = new SubtitleLine();
-	const int newLineIndex = (target == Secondary) ? m_lines.count() : index;
+	const int newLineIndex = (target == Secondary) ? m_lines.size() : index;
 
 	const double linePause = (double)SCConfig::linePause();
 	const double lineDuration = (double)SCConfig::lineDuration();
@@ -438,11 +436,11 @@ Subtitle::insertNewLine(int index, bool insertAfter, SubtitleTarget target)
 void
 Subtitle::removeLines(const RangeList &r, SubtitleTarget target)
 {
-	if(m_lines.isEmpty())
+	if(m_lines.empty())
 		return;
 
 	RangeList ranges = r;
-	ranges.trimToIndex(m_lines.count() - 1);
+	ranges.trimToIndex(m_lines.size() - 1);
 
 	if(ranges.isEmpty())
 		return;
@@ -461,7 +459,7 @@ Subtitle::removeLines(const RangeList &r, SubtitleTarget target)
 		beginCompositeAction(i18n("Remove Lines"));
 
 		RangeList rangesComplement = ranges.complement();
-		rangesComplement.trimToRange(Range(ranges.firstIndex(), m_lines.count() - 1));
+		rangesComplement.trimToRange(Range(ranges.firstIndex(), m_lines.size() - 1));
 
 		// we have to move the secondary texts up (we do it in chunks)
 		SubtitleIterator srcIt(*this, rangesComplement);
@@ -478,12 +476,12 @@ Subtitle::removeLines(const RangeList &r, SubtitleTarget target)
 		beginCompositeAction(i18n("Remove Lines"));
 
 		RangeList mutableRanges(ranges);
-		mutableRanges.trimToIndex(m_lines.count() - 1);
+		mutableRanges.trimToIndex(m_lines.size() - 1);
 
 		// first, we need to append as many empty lines as we're to remove
 		// we insert them with a greater time than the one of the last (non deleted) line
 
-		int linesCount = m_lines.count();
+		int linesCount = m_lines.size();
 
 		Range lastRange = mutableRanges.last();
 		int lastIndex = lastRange.end() == linesCount - 1 ? lastRange.start() - 1 : linesCount - 1;
@@ -503,7 +501,7 @@ Subtitle::removeLines(const RangeList &r, SubtitleTarget target)
 		// then, we move the secondary texts down (we need to iterate from bottom to top for that)
 		RangeList rangesComplement = mutableRanges.complement();
 
-		SubtitleIterator srcIt(*this, Range(ranges.firstIndex(), m_lines.count() - lines.count() - 1), true);
+		SubtitleIterator srcIt(*this, Range(ranges.firstIndex(), m_lines.size() - lines.count() - 1), true);
 		SubtitleIterator dstIt(*this, rangesComplement, true);
 		for(; srcIt.current() && dstIt.current(); --srcIt, --dstIt)
 			dstIt.current()->secondaryDoc()->setRichText(srcIt.current()->secondaryDoc()->toRichText());
@@ -682,7 +680,7 @@ Subtitle::joinLines(const RangeList &ranges)
 void
 Subtitle::shiftAnchoredLine(SubtitleLine *anchoredLine, const Time &newShowTime)
 {
-	if(m_anchoredLines.indexOf(anchoredLine) == -1 || m_lines.isEmpty())
+	if(m_anchoredLines.indexOf(anchoredLine) == -1 || m_lines.empty())
 		return;
 
 	const SubtitleLine *prevAnchor = nullptr;
@@ -761,7 +759,7 @@ Subtitle::shiftLines(const RangeList &ranges, long msecs)
 void
 Subtitle::adjustLines(const Range &range, long newFirstTime, long newLastTime)
 {
-	if(m_lines.isEmpty() || newFirstTime >= newLastTime)
+	if(m_lines.empty() || newFirstTime >= newLastTime)
 		return;
 
 	int firstIndex = range.start();
@@ -836,7 +834,7 @@ Subtitle::sortLines(const Range &range)
 void
 Subtitle::applyDurationLimits(const RangeList &ranges, const Time &minDuration, const Time &maxDuration, bool canOverlap)
 {
-	if(m_lines.isEmpty() || minDuration > maxDuration)
+	if(m_lines.empty() || minDuration > maxDuration)
 		return;
 
 	beginCompositeAction(i18n("Enforce Duration Limits"));
@@ -875,7 +873,7 @@ Subtitle::applyDurationLimits(const RangeList &ranges, const Time &minDuration,
 void
 Subtitle::setMaximumDurations(const RangeList &ranges)
 {
-	if(m_lines.isEmpty())
+	if(m_lines.empty())
 		return;
 
 	beginCompositeAction(i18n("Maximize Durations"));
@@ -898,7 +896,7 @@ Subtitle::setMaximumDurations(const RangeList &ranges)
 void
 Subtitle::setAutoDurations(const RangeList &ranges, int msecsPerChar, int msecsPerWord, int msecsPerLine, bool canOverlap, SubtitleTarget calculationTarget)
 {
-	if(m_lines.isEmpty())
+	if(m_lines.empty())
 		return;
 
 	beginCompositeAction(i18n("Set Automatic Durations"));
@@ -931,7 +929,7 @@ Subtitle::setAutoDurations(const RangeList &ranges, int msecsPerChar, int msecsP
 void
 Subtitle::fixOverlappingLines(const RangeList &ranges, const Time &minInterval)
 {
-	if(m_lines.isEmpty())
+	if(m_lines.empty())
 		return;
 
 	beginCompositeAction(i18n("Fix Overlapping Times"));
@@ -962,7 +960,7 @@ Subtitle::fixOverlappingLines(const RangeList &ranges, const Time &minInterval)
 void
 Subtitle::fixPunctuation(const RangeList &ranges, bool spaces, bool quotes, bool engI, bool ellipsis, SubtitleTarget target)
 {
-	if(m_lines.isEmpty() || (!spaces && !quotes && !engI && !ellipsis) || target >= SubtitleTargetSize)
+	if(m_lines.empty() || (!spaces && !quotes && !engI && !ellipsis) || target >= SubtitleTargetSize)
 		return;
 
 	beginCompositeAction(i18n("Fix Lines Punctuation"));
@@ -1004,7 +1002,7 @@ Subtitle::fixPunctuation(const RangeList &ranges, bool spaces, bool quotes, bool
 void
 Subtitle::lowerCase(const RangeList &ranges, SubtitleTarget target)
 {
-	if(m_lines.isEmpty() || target >= SubtitleTargetSize)
+	if(m_lines.empty() || target >= SubtitleTargetSize)
 		return;
 
 	beginCompositeAction(i18n("Lower Case"));
@@ -1034,7 +1032,7 @@ Subtitle::lowerCase(const RangeList &ranges, SubtitleTarget target)
 void
 Subtitle::upperCase(const RangeList &ranges, SubtitleTarget target)
 {
-	if(m_lines.isEmpty() || target >= SubtitleTargetSize)
+	if(m_lines.empty() || target >= SubtitleTargetSize)
 		return;
 
 	beginCompositeAction(i18n("Upper Case"));
@@ -1064,7 +1062,7 @@ Subtitle::upperCase(const RangeList &ranges, SubtitleTarget target)
 void
 Subtitle::titleCase(const RangeList &ranges, bool lowerFirst, SubtitleTarget target)
 {
-	if(m_lines.isEmpty() || target >= SubtitleTargetSize)
+	if(m_lines.empty() || target >= SubtitleTargetSize)
 		return;
 
 	beginCompositeAction(i18n("Title Case"));
@@ -1097,7 +1095,7 @@ Subtitle::titleCase(const RangeList &ranges, bool lowerFirst, SubtitleTarget tar
 void
 Subtitle::sentenceCase(const RangeList &ranges, bool lowerFirst, SubtitleTarget target)
 {
-	if(m_lines.isEmpty() || target >= SubtitleTargetSize)
+	if(m_lines.empty() || target >= SubtitleTargetSize)
 		return;
 
 	beginCompositeAction(i18n("Sentence Case"));
@@ -1206,7 +1204,7 @@ Subtitle::appendSubtitle(const Subtitle &srcSubtitle, double shiftMsecsBeforeApp
 void
 Subtitle::splitSubtitle(Subtitle &dstSubtitle, const Time &splitTime, bool shiftSplitLines)
 {
-	if(!m_lines.count())
+	if(m_lines.empty())
 		return;
 
 	int splitIndex = -1; // the index of the first line to move (or copy) to dstSub
