@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -90,13 +90,12 @@ InsertLinesAction::redo()
 
 	SubtitleLine *line;
 	int insertOffset = 0;
-	int lineIndex = -1;
 
 	while(!m_lines.isEmpty()) {
 		line = m_lines.takeFirst();
-		lineIndex = m_insertIndex + insertOffset++;
+		auto pos = m_subtitle->m_lines.cbegin() + m_insertIndex + insertOffset++;
 		setLineSubtitle(line);
-		m_subtitle->m_lines.insert(lineIndex, line);
+		m_subtitle->m_lines.insert(pos, line);
 	}
 
 	emit m_subtitle->linesInserted(m_insertIndex, m_lastIndex);
@@ -182,13 +181,12 @@ RemoveLinesAction::undo()
 	emit m_subtitle->linesAboutToBeInserted(m_firstIndex, m_lastIndex);
 
 	int insertOffset = 0;
-	int lineIndex = -1;
 
 	while(!m_lines.isEmpty()) {
 		SubtitleLine *line = m_lines.takeFirst();
-		lineIndex = m_firstIndex + insertOffset++;
+		auto pos = m_subtitle->m_lines.cbegin() + m_firstIndex + insertOffset++;
 		setLineSubtitle(line);
-		m_subtitle->m_lines.insert(lineIndex, line);
+		m_subtitle->m_lines.insert(pos, line);
 	}
 
 	emit m_subtitle->linesInserted(m_firstIndex, m_lastIndex);
@@ -261,7 +259,7 @@ MoveLineAction::redo()
 
 	emit m_subtitle->linesAboutToBeInserted(m_toIndex, m_toIndex);
 	setLineSubtitle(line);
-	m_subtitle->m_lines.insert(m_toIndex, line);
+	m_subtitle->m_lines.insert(m_subtitle->m_lines.cbegin() + m_toIndex, line);
 	emit m_subtitle->linesInserted(m_toIndex, m_toIndex);
 }
 
@@ -275,7 +273,7 @@ MoveLineAction::undo()
 
 	emit m_subtitle->linesAboutToBeInserted(m_fromIndex, m_fromIndex);
 	setLineSubtitle(line);
-	m_subtitle->m_lines.insert(m_fromIndex, line);
+	m_subtitle->m_lines.insert(m_subtitle->m_lines.cbegin() + m_fromIndex, line);
 	emit m_subtitle->linesInserted(m_fromIndex, m_fromIndex);
 }
 
