@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2017-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -63,7 +63,7 @@ public:
 		linesWidget->setSubtitle(&subtitle);
 
 		// show process dialog
-		VobSubInputProcessDialog dlgProc(&subtitle, app()->mainWindow());
+		VobSubInputProcessDialog dlgProc(&subtitle, dlgInit.whitespaceThreshold(), app()->mainWindow());
 
 		dlgProc.processFrames(&proc);
 
