@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2017-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,6 +33,12 @@ VobSubInputInitDialog::streamIndex() const
 	return ui->comboStream->currentIndex();
 }
 
+qint32
+VobSubInputInitDialog::whitespaceThreshold() const
+{
+	return ui->hsWhitespace->value() - ui->hsWhitespace->maximum() / 2;
+}
+
 quint32
 VobSubInputInitDialog::postProcessingFlags() const
 {
