@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,6 @@
 #include "gui/playerwidget.h"
 #include "gui/treeview/lineswidget.h"
 #include "gui/currentlinewidget.h"
-#include "videoplayer/videoplayer.h"
 #include "gui/waveform/waveformwidget.h"
 #include "gui/subtitlemeta/subtitlemetawidget.h"
 
@@ -32,7 +31,19 @@ using namespace SubtitleComposer;
 MainWindow::MainWindow()
 	: KXmlGuiWindow(nullptr)
 {
-	VideoPlayer::instance()->setParent(this);
+	QDockWidget *playerDock = new QDockWidget(i18n("Video Player"), this);
+	playerDock->setObjectName(QStringLiteral("player_dock"));
+	playerDock->setAllowedAreas(Qt::AllDockWidgetAreas);
+	playerDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetVerticalTitleBar);
+	playerDock->setFloating(false);
+
+	m_playerWidget = new PlayerWidget(playerDock);
+	m_playerWidget->setContentsMargins(0, 0, 0, 0);
+
+	playerDock->setWidget(m_playerWidget);
+	playerDock->setTitleBarWidget(m_playerWidget->infoSidebarWidget());
+	addDockWidget(Qt::TopDockWidgetArea, playerDock);
+
 
 	QDockWidget *waveformDock = new QDockWidget(i18n("Waveform"), this);
 	waveformDock->setObjectName(QStringLiteral("waveform_dock"));
@@ -48,20 +59,6 @@ MainWindow::MainWindow()
 	addDockWidget(Qt::RightDockWidgetArea, waveformDock);
 
 
-	QDockWidget *playerDock = new QDockWidget(i18n("Video Player"), this);
-	playerDock->setObjectName(QStringLiteral("player_dock"));
-	playerDock->setAllowedAreas(Qt::AllDockWidgetAreas);
-	playerDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetVerticalTitleBar);
-	playerDock->setFloating(false);
-
-	m_playerWidget = new PlayerWidget(playerDock);
-	m_playerWidget->setContentsMargins(0, 0, 0, 0);
-
-	playerDock->setWidget(m_playerWidget);
-	playerDock->setTitleBarWidget(m_playerWidget->infoSidebarWidget());
-	addDockWidget(Qt::TopDockWidgetArea, playerDock);
-
-
 	QDockWidget *cssDock = new QDockWidget(i18n("Styles and Comments"), this);
 	cssDock->setObjectName(QStringLiteral("submeta_dock"));
 	cssDock->setAllowedAreas(Qt::AllDockWidgetAreas);
