@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2018 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,10 +36,10 @@ public slots:
 	void clear();
 
 	void trimToIndex(int index);
-	void trimToRange(const QObject *range);
+	void trimToRange(QObject *range);
 
 	QObject * addIndex(int index);
-	QObject * addRange(const QObject *range);
+	QObject * addRange(QObject *range);
 
 	void shiftIndexesForwards(int fromIndex, int delta, bool fillSplitGap);
 	void shiftIndexesBackwards(int fromIndex, int delta);
