@@ -1,14 +1,12 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2018 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "scripting_stringsmodule.h"
-#include "scripting_sstring.h"
-
-#include <QRegExp>
+#include "scripting_richstring.h"
 
 using namespace SubtitleComposer;
 
@@ -19,7 +17,7 @@ Scripting::StringsModule::StringsModule(QObject *parent) :
 QObject *
 Scripting::StringsModule::newString(const QString &text)
 {
-	return new SString(SubtitleComposer::SString(text), this);
+	return new RichString(SubtitleComposer::RichString(text), this);
 }
 
 
