@@ -1,14 +1,15 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2018 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "scripting_subtitlemodule.h"
-#include "scripting_subtitle.h"
+
+#include "appglobal.h"
 #include "application.h"
-#include "core/subtitletarget.h"
+#include "scripting_subtitle.h"
 
 using namespace SubtitleComposer;
 
@@ -19,7 +20,7 @@ Scripting::SubtitleModule::SubtitleModule(QObject *parent) :
 QObject *
 Scripting::SubtitleModule::instance()
 {
-	return app()->subtitle() ? new Scripting::Subtitle(app()->subtitle(), this) : 0;
+	return appSubtitle() ? new Scripting::Subtitle(appSubtitle(), this) : nullptr;
 }
 
 bool
