@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2021 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2021-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,11 +8,24 @@
 
 #include <QTest>
 
-#include "application.h"
-#include "core/richdocument.h"
+#include "core/richtext/richdocument.h"
+
+#include <klocalizedstring.h>
 
 using namespace SubtitleComposer;
 
+
+SubtitleTest::SubtitleTest()
+	: sub(new SubtitleComposer::Subtitle)
+{
+	KLocalizedString::setApplicationDomain("subtitlecomposer");
+}
+
+SubtitleTest::~SubtitleTest()
+{
+	sub.reset();
+}
+
 void
 SubtitleTest::testSort_data()
 {
@@ -33,18 +46,17 @@ SubtitleTest::testSort()
 {
 	QFETCH(QVector<int>, lines);
 
-	sub.removeLines(RangeList(Range::full()), SubtitleTarget::Both);
+	sub->removeLines(RangeList(Range::full()), SubtitleTarget::Both);
 
 	for(int n: lines) {
 		SubtitleLine *l = new SubtitleLine(n * 1000, n * 1000 + 500);
 		l->primaryDoc()->setPlainText(QString::number(n));
-		sub.insertLine(l);
+		sub->insertLine(l);
 	}
 
-	QVERIFY(sub.count() == lines.size());
-	for(int i = 0; i < sub.count(); i++)
-		QVERIFY(qRound(sub.at(i)->showTime().toSeconds()) == i + 1);
+	QVERIFY(sub->count() == lines.size());
+	for(int i = 0; i < sub->count(); i++)
+		QVERIFY(qRound(sub->at(i)->showTime().toSeconds()) == i + 1);
 }
 
-#define QCoreApplication Application
-QTEST_GUILESS_MAIN(SubtitleTest);
+QTEST_MAIN(SubtitleTest);
