@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2023 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2023-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,7 +31,7 @@ public:
 	void translate(QVector<QString> &textLines) override;
 
 private:
-	bool parseJSON();
+	bool parseJSON(const QString &serviceJSONFile);
 	void login();
 	bool authenticate();
 	void authenticated();
