@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2003 Fabrice Bellard
-    SPDX-FileCopyrightText: 2020-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2020-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -55,6 +55,10 @@ protected:
 	AVRational m_startPtsTb;
 	int64_t m_nextPts;
 	AVRational m_nextPtsTb;
+
+	struct FrameData {
+		int64_t pkt_pos;
+	};
 };
 }
 
