@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2003 Fabrice Bellard
-    SPDX-FileCopyrightText: 2020-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2020-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,7 +38,7 @@ class FFPlayer : public QObject {
 	Q_OBJECT
 
 public:
-	FFPlayer(QObject *parent=nullptr);
+	FFPlayer(QWidget *parentWidget, QObject *parent=nullptr);
 	virtual ~FFPlayer();
 
 	static uint8_t *flushPkt();
