@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2020-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2020-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -79,10 +79,6 @@ GLRenderer::GLRenderer(QWidget *parent)
 	  m_idTex(nullptr),
 	  m_vaBuf(nullptr)
 {
-	// NOTE: Qt6.7 QOpenGLWidget breaks main window rendering after reparenting during fullscreen transition
-	setAttribute(Qt::WA_NativeWindow, true); // making it native window borks only parent widget rendering
-	winId(); // this should create native window immediately? and no rendering gets borked
-
 	setUpdateBehavior(NoPartialUpdate);
 }
 
@@ -109,8 +105,10 @@ void
 GLRenderer::setupProfile()
 {
 	QSurfaceFormat format(QSurfaceFormat::defaultFormat());
-#if FORCE_GLES
+#if FORCE_GLES || defined(USE_GLES)
 	format.setRenderableType(QSurfaceFormat::OpenGLES);
+#else
+	format.setRenderableType(QSurfaceFormat::OpenGL);
 #endif
 	format.setVersion(OPENGL_VER);
 #if DEBUG_GL
@@ -576,7 +574,7 @@ GLRenderer::initializeGL()
 	}
 	asGL(glGenTextures(ID_SIZE, m_idTex));
 
-	asGL(glClearColor(.0f, .0f, .0f, .0f)); // background color
+	asGL(glClearColor(.0f, .0f, .0f, 1.f)); // background color
 
 	asGL(glDisable(GL_DEPTH_TEST));
 
@@ -607,7 +605,7 @@ GLRenderer::paintGL()
 {
 	QMutexLocker l(&m_texMutex);
 
-	glClear(GL_COLOR_BUFFER_BIT);
+	asGL(glClear(GL_COLOR_BUFFER_BIT));
 
 	if(!m_bufYUV)
 		return;
