@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2003 Fabrice Bellard
-    SPDX-FileCopyrightText: 2020-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2020-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,7 +33,7 @@ private:
 	void videoRefresh(double *remainingTime);
 	void videoDisplay();
 	double vpDuration(Frame *vp, Frame *nextvp);
-	void updateVideoPts(double pts, int64_t pos, int serial);
+	void updateVideoPts(double pts, int serial);
 	double computeTargetDelay(double delay);
 	void updateSampleDisplay(short *samples, int samplesSize);
 	void toggleAudioDisplay();
