@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -113,6 +113,8 @@ SubtitleTextOverlay::drawDocPrepare(QPainter *painter)
 void
 SubtitleTextOverlay::drawDoc()
 {
+	if(m_image.isNull())
+		return;
 	QPainter painter(&m_image);
 	painter.setRenderHints(QPainter::Antialiasing | QPainter::TextAntialiasing | QPainter::SmoothPixmapTransform, true);
 	painter.setFont(m_font);
@@ -205,6 +207,7 @@ SubtitleTextOverlay::setText(const QString &text)
 {
 	if(!m_text) {
 		m_text = new RichDocument(this);
+		m_text->setStylesheet(new RichCSS(this));
 	} else if(m_text->toHtml() == text) {
 		return;
 	}
