@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,6 +26,9 @@ class VideoPlayer : public QObject
 	Q_OBJECT
 
 public:
+	VideoPlayer(QWidget *videoContainer);
+	virtual ~VideoPlayer();
+
 	enum State {
 		Initialized,
 		Opening,
@@ -34,9 +37,7 @@ public:
 		Paused
 	};
 
-	static VideoPlayer * instance();
-
-	bool init(QWidget *videoContainer);
+	bool init();
 
 	inline State state() const { return m_state; }
 	inline VideoWidget * videoWidget() { return m_videoWidget; }
@@ -60,6 +61,8 @@ public:
 
 	inline SubtitleTextOverlay & subtitleOverlay() { return m_subOverlay; }
 
+	inline GLRenderer * renderer() const { return m_player->renderer(); }
+
 	bool playOnLoad();
 
 public slots:
@@ -106,15 +109,12 @@ signals:
 	void wheelDown();
 
 private:
-	VideoPlayer();
-	virtual ~VideoPlayer();
-
 	void reset();
 	void setupNotifications();
 
 private:
-	FFPlayer *m_player;
 	VideoWidget *m_videoWidget;
+	FFPlayer *m_player;
 	SubtitleTextOverlay m_subOverlay;
 	QString m_filePath;
 
