@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2025 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,9 +26,6 @@ public:
 	explicit VideoWidget(QWidget *parent);
 	virtual ~VideoWidget();
 
-	QWidget * videoLayer() const;
-	void setVideoLayer(QWidget *videoLayer);
-
 	int videoWidth() const;
 	int videoHeight() const;
 	double videoDAR() const;
@@ -69,8 +66,6 @@ protected:
 	void wheelEvent(QWheelEvent *e) override;
 
 protected:
-	QWidget *m_videoLayer;
-
 	int m_videoWidth;
 	int m_videoHeight;
 	double m_videoDAR;
