@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2020 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,6 @@ using namespace SubtitleComposer;
 TextOverlayWidget::TextOverlayWidget(QWidget *parent)
 	: QWidget(parent)
 {
-	parent->installEventFilter(this);
 }
 
 TextOverlayWidget::~TextOverlayWidget()
@@ -27,17 +26,20 @@ TextOverlayWidget::~TextOverlayWidget()
 
 QSize
 TextOverlayWidget::minimumSizeHint() const
+{
+	return QSize(100, m_overlay.textSize().height());
+}
+
+QSize
+TextOverlayWidget::sizeHint() const
 {
 	return m_overlay.textSize();
 }
 
-bool
-TextOverlayWidget::eventFilter(QObject *object, QEvent *event)
+void
+TextOverlayWidget::resizeEvent(QResizeEvent *event)
 {
-	if(object == parentWidget() && event->type() == QEvent::Resize)
-		m_overlay.setImageSize(parentWidget()->size());
-
-	return QWidget::eventFilter(object, event);
+	m_overlay.setImageSize(event->size());
 }
 
 void
@@ -45,6 +47,10 @@ TextOverlayWidget::paintEvent(QPaintEvent * /*event */)
 {
 	QPainter painter(this);
 	painter.fillRect(rect(), Qt::transparent);
-	const int offY = height() - contentsMargins().bottom() - m_overlay.textSize().height();
-	painter.drawImage(0, offY, m_overlay.image());
+	const QImage &img = m_overlay.image();
+	const int imgCenterX = img.width() / 2;
+	const int widgetHalfWidth = width() / 2;
+	const QRect src(imgCenterX - widgetHalfWidth, height() - m_overlay.textSize().height(),
+					imgCenterX + widgetHalfWidth, height());
+	painter.drawImage(rect(), img, src);
 }
